@@ -1,5 +1,6 @@
 from collections import OrderedDict
 from types import FunctionType
+from typing import Any, Dict, Set
 
 from .exceptions import Error, Extra, Missing, ValidationError
 from .fields import Field
@@ -55,14 +56,29 @@ class MetaModel(type):
             field_config = config_fields.get(var_name)
             if isinstance(field_config, str):
                 field_config = {'alias': field_config}
-            field = Field.infer(
+            fields[var_name] = Field.infer(
                 name=var_name,
                 value=value,
-                annotation=annotations and annotations.get(var_name),
+                annotation=annotations and annotations.pop(var_name, None),
                 class_validators=class_validators,
                 field_config=field_config,
             )
-            fields[var_name] = field
+
+        if annotations:
+            for ann_name, ann_type in annotations.items():
+                if ann_name.startswith('_'):
+                    continue
+                field_config = config_fields.get(ann_name)
+                if isinstance(field_config, str):
+                    field_config = {'alias': field_config}
+                fields[ann_name] = Field.infer(
+                    name=ann_name,
+                    value=...,
+                    annotation=ann_type,
+                    class_validators=class_validators,
+                    field_config=field_config,
+                )
+
         namespace.update(
             config=config,
             __fields__=fields,
@@ -78,9 +94,10 @@ EXTRA_ERROR = Error(Extra('extra fields not permitted'), None, None)
 class BaseModel(metaclass=MetaModel):
     # populated by the metaclass, defined here to help IDEs only
     __fields__ = {}
+    Config = BaseConfig
 
     def __init__(self, **values):
-        self.__values__ = {}
+        self.__values__ = OrderedDict()
         self.__errors__ = OrderedDict()
         self._process_values(values)
 
@@ -95,9 +112,16 @@ class BaseModel(metaclass=MetaModel):
         setattr(self, name, value)
         self.__values__[name] = value
 
-    @property
-    def values(self):
-        return dict(self)
+    def values(self, *, include: Set[str]=None, exclude: Set[str]=set()) -> Dict[str, Any]:
+        """
+        Get a dict of the values processed by the model, optionally specifying which fields to include or exclude.
+
+        This is NOT equivalent to the values() method on a dict.
+        """
+        return {
+            k: v for k, v in self
+            if k not in exclude and (not include or k in include)
+        }
 
     @property
     def fields(self):
@@ -159,7 +183,7 @@ class BaseModel(metaclass=MetaModel):
     @classmethod
     def _get_value(cls, v):
         if isinstance(v, BaseModel):
-            return v.values
+            return v.values()
         elif isinstance(v, list):
             return [cls._get_value(v_) for v_ in v]
         elif isinstance(v, dict):
@@ -178,13 +202,31 @@ class BaseModel(metaclass=MetaModel):
 
     def __eq__(self, other):
         if isinstance(other, BaseModel):
-            return self.values == other.values
+            return self.values() == other.values()
         else:
-            return self.values == other
+            return self.values() == other
 
     def __repr__(self):
         return f'<{self}>'
 
+    @classmethod
+    def _truncate(cls, v):
+        max_len = 80
+        if isinstance(v, str) and len(v) > (max_len - 2):
+            # 45 so quote + string + ... + quote has length 50
+            return repr(v[:(max_len - 5)] + '...')
+        v = repr(v)
+        if len(v) > max_len:
+            v = v[:max_len - 3] + '...'
+        return v
+
+    def to_string(self, pretty=False):
+        divider = '\n  ' if pretty else ' '
+        return '{}{}{}'.format(
+            self.__class__.__name__,
+            divider,
+            divider.join('{}={}'.format(k, self._truncate(v)) for k, v in self.__values__.items()),
+        )
+
     def __str__(self):
-        return '{} {}'.format(self.__class__.__name__, ' '.join('{}={!r}'.format(k, v)
-                                                                for k, v in self.__values__.items()))
+        return self.to_string()
